Loose wishlist of things to achieve.
Please also consult https://github.com/infothrill/python-dyndnsc/issues

Python version related
----------------------

* python 3.3 introduced a new stdlib module 'ipaddress'
   http://docs.python.org/3/library/ipaddress.html
  potentially replacing the need for IPy. It's also backported for older python
  versions at https://pypi.python.org/pypi/ipaddress


Dyndns update services support
------------------------------

* http://www.dnsdynamic.org/api.php
   https://username:password@www.dnsdynamic.org/api/?hostname=techno.ns360.info&myip=127.0.0.1

* http://freedns.afraid.org/scripts/freedns.clients.php
   http://freedns.afraid.org/dynamic/update.php?YOUR-SECRET-KEY-HERE
   